/*
#
#   hcal version 1.0 - postscript hebrew calendar generator
#   copyright 1994,1995 - Steven Weintraub
#
#   This program is modified and distribed by Steven Weintraub.  It
#   can be freely distributed without permission as long as this
#   head is retained in all files it appears and the LICENCE file
#   accompanies it.
#
*/

#define LEAP(x) (!((x) % 4) && ( ((x) % 100) || !((x) % 400)))
#define DAYS_IN(x) (LEAP((x))?366:365)

#define JAN 0
#define FEB 1
#define MAR 2
#define APR 3
#define MAY 4
#define JUN 5
#define JUL 6
#define AUG 7
#define SEP 8
#define OCT 9
#define NOV 10
#define DEC 11

#define SUNDAY 0
#define MONDAY 1
#define TUESDAY 2
#define WEDNESDAY 3
#define THURSDAY 4
#define FRIDAY 5
#define SATURDAY 6

#define MAXDAYS 31
#define JUL2HEB(x) ((x)+ 3760)
#define MAX_LINE_LEN 100

#define LAST_INDEX(x) (sizeof x / sizeof x[0])

typedef struct {
  int mm;	/* months since january 0,11*/
  int dd;	/* day of month 1,31 */
  int yy;	/* years since year 1 BCE i.e. -1 = 2 BCE */
  } date_t;

typedef struct {

  char * name;
  int length;

  int daysInCheshvan;
  int daysInKislev;

  int vayakhelPikudei;	/* double parsha flags */
  int tazriaMetzorah;
  int achreiKedoshim;
  int beharBech;
  int chukatBalak;
  int matotMasei;
  int nitzavimVayelech;

} year_t;

struct special_parshot {
  char *sephardic_name;
  char *ashkenazic_name;
  int   addname;    /* 0 = no,1 = replace,2 = append */
  int   base_month;
  int   base_day;
  int   days_from_base;
  int   number_of_days;
  char *torah;
  char *ashkenazic_prophet;
  char *sephardic_prophet;
};

typedef struct hinode{   /* holiday input structure */
	date_t date;
	char *(name[2]);
  int typeMask;
  struct hinode *next;
} holinput_t, *holinputp_t;

typedef struct hsnode{  /* holiday storage structure */
	char *name;
  int typeMask;
  struct hsnode *next;
} holstore_t, *holstorep_t;

#if defined(PROTOTYPES)
static year_t yearData(int yr);
static int daysInHebMonth(int month,int year);
static date_t nextHebDate (date_t dth);
static date_t prevHebDate (date_t dth);
static holstorep_t getHolstorep(char *s);
static int PushHoliday(holstorep_t hp,holstorep_t *lp);
static void getHebHolidays (date_t dth,int weekday, holstorep_t *holiList);
static void incHebJulDate(date_t *dth,date_t *dtj,int *wkday);
static char *DoSedra (int *sedra,year_t ydat);
static void DoCalendar (date_t myDate,day_data_t *day_data);
static void RollBack(date_t *dtg,int target);
static void RollForward(date_t *dtg,int target);
static long int daysSinceOrigin (date_t dt);
static void decDate (date_t *dt,int n);
static void incDate (date_t *dt,int n);
static int dayOfWeek(date_t d1);
#else
static year_t yearData();
static int daysInHebMonth();
static date_t nextHebDate ();
static date_t prevHebDate ();
static holstorep_t getHolstorep();
static int PushHoliday();
static void getHebHolidays ();
static void incHebJulDate();
static char *DoSedra ();
static void DoCalendar ();
static void RollBack();
static void RollForward();
static long int daysSinceOrigin ();
static void decDate ();
static void incDate ();
static int dayOfWeek();
#endif
