static char version[] =
"hcal version 1.0 - postscript hebrew calendar generator\n\n\
copyright 1994,1995 - Steven Weintraub";

/*
 
    hcal version 1.0 - postscript hebrew calendar generator
    copyright 1994,1995 - Steven Weintraub
 
    This program is created and distribed by Steven Weintraub. It
    can be freely distributed without permission as long as this
    head is retained in all files it appears and the LICENCE file
    accompanies it.
 
*/

#include "hcal.h"

#if defined(PROTOTYPES)
void directions(void) {
#else
void directions() {
#endif
	fprintf(stderr,"Usage : %s -aClqSv -m <month> -y <year> -c <city> -o <output_file>\n            -t <template_file> -p <postscript_file> -s <schedule_file>\n           -B <margin> -T <margin> -L<margin> -R<margin>",program);
	fprintf(stderr,"\n");
	fprintf(stderr,"where :\n");
	fprintf(stderr,"\n");
	fprintf(stderr,"-a          : Use Ashkenazic transliterations (default use Sephardic)\n");
#ifdef XCURSES
	fprintf(stderr,"-bg <color> : Set your bcakground color to <color>\n");
#endif
	fprintf(stderr,"-B <margin> : Set bottom margin to <margin> points\n");
	fprintf(stderr,"-c <city>   : Set your city to <city>\n");
#ifdef XCURSES
	fprintf(stderr,"-display <display>: Set your display to <display>\n");
	fprintf(stderr,"-fg <color> : Set your foreground color to <color>\n");
	fprintf(stderr,"-i          : Start interactive calendar as icon\n");
	fprintf(stderr,"-I          : Do not have interactive calendar as icon\n");
#endif
	fprintf(stderr,"-l          : Do not print licence information at begining of program\n");
	fprintf(stderr,"-L <margin> : Set left margin to <margin> points\n");
	fprintf(stderr,"-m <month>  : Set month to print as <month>\n");
	fprintf(stderr,"-o <file>   : Use <file> as the input/output data file\n");
	fprintf(stderr,"-p <file>   : Use <file> as the postscript output file\n");
	fprintf(stderr,"-q          : Act quietly - do not do interactive actions or print\n");
	fprintf(stderr,"              inocculous warnings\n");
	fprintf(stderr,"-R <margin> : Set right margin to <margin> points\n");
	fprintf(stderr,"-s <file>   : Use <file> as the schedule output file\n");
	fprintf(stderr,"-S          : Use Sephardic Prophet readings (default use Ashkenazic)\n");
	fprintf(stderr,"-t <file>   : Use <file> as the generic template file\n");
	fprintf(stderr,"-T <margin> : Set top margin to <margin> points\n");
	fprintf(stderr,"-v          : Print program version\n");
	fprintf(stderr,"-y <year>   : Set year to print as <year>\n");
#ifdef XCURSES
	fprintf(stderr,"-z <lines>  : Set lines of screen to <lines>\n");
#endif
	exit(0);
}

#if defined(PROTOTYPES)
char *param_arg(char **av,int *ac,char **argv,int argc) {
#else
char *param_arg(av,ac,argv,argc)
char **av;int *ac;char **argv;int argc; {
#endif
	char	arg;
	char	*avb;

	arg = **av;
	/* increment av */
	avb = *av;
	avb++;
	/* if av is empty - check next parameter for optarg */
	if (!*avb) {
		/* make sure next param exists and not another parameter (-) */
		if (++*ac < argc) {
			avb = argv[*ac];
			if (*avb == '-') {
				fprintf(stderr,
					"No value specified after -%c\n",arg);
				exit(1);
			}
		} else {
			fprintf(stderr,"No value specified after -%c\\nn",arg);
			exit(1);
		}
	}
	return(avb);
}

#if defined(PROTOTYPES)
void parse_args(int argc,char *argv[]) {
#else
void parse_args(argc,argv) int argc;char **argv; {
#endif
	int	 ac;
	char	*av;
	char	*flag_m = NULL;
	char	*flag_y = NULL;
	int	 flag_v = NO;
	int	 more;

	program = argv[0];

/* parse arguements */
	for (ac = 1;ac < argc;ac++) {
		av = argv[ac];
/*  process if parameter is a flag (-) */
		if (*av == '-') {
			av++;
			more = YES;
			while (*av && more) {
				switch (*av) {
					case 'a':
						flag_a = YES;
						break;
#ifdef XCURSES
					case 'b':
						if (strcmp("bg",av) == 0)
						  av ++;
						cur_background_color_name = 
						   param_arg(&av,&ac,argv,argc);
						break;
#endif
					case 'B':
						margin_bottom = atoi(param_arg(
							&av,&ac,argv,argc));
						break;
					case 'C':
						flag_C = YES;
						break;
					case 'c':
						flag_c = param_arg(&av,&ac,argv,
								argc);
						more = NO;
						break;
#ifdef XCURSES
					case 'd':
						if (strcmp("display",av) == 0)
						  av += 6;
						cur_display_name = 
						   param_arg(&av,&ac,argv,argc);
						break;
#endif
#ifdef XCURSES
					case 'f':
						if (strcmp("fg",av) == 0)
						  av++;
						cur_foreground_color_name = 
						   param_arg(&av,&ac,argv,argc);
						break;
#endif
#ifdef XCURSES
					case 'i':
						flag_i = YES;
						break;
#endif
#ifdef XCURSES
					case 'I':
						flag_I = YES;
						break;
#endif
					case 'l':
						flag_L = YES;
						break;
					case 'L':
						margin_left = atoi(param_arg(
							&av,&ac,argv,argc));
						break;
					case 'm':
						flag_m = param_arg(&av,&ac,argv,
								argc);
						more = NO;
						break;
					case 'o':
						flag_o = param_arg(&av,&ac,argv,
								argc);
						more = NO;
						break;
					case 'p':
						flag_p = param_arg(&av,&ac,argv,
								argc);
						more = NO;
						break;
					case 'q':
						flag_q = YES;
						break;
					case 'R':
						margin_right = atoi(param_arg(
							&av,&ac,argv,argc));
						break;
					case 'S':
						flag_S = YES;
						break;
					case 's':
						flag_s = param_arg(&av,&ac,argv,
								argc);
						more = NO;
						break;
					case 'T':
						margin_top = atoi(param_arg(&av,
								&ac,argv,argc));
						break;
					case 't':
						flag_t = param_arg(&av,&ac,argv,
								argc);
						more = NO;
						break;
					case 'v':
						flag_v = YES;
						break;
					case 'y':
						flag_y = param_arg(&av,&ac,argv,
								argc);
						more = NO;
						break;
#ifdef DCURSES
					case 'z':
						cur_lines = atoi(param_arg(
							&av,&ac,argv,argc));
						break;
#endif
					case '?':
						directions();
						break;
					default:
						fprintf(stderr,
						   "Unknown option '%c'\n",*av);
						directions();
						break;
				}
				av++;
			}
		} else {
			fprintf(stderr,"Unknown command line argument '%s'\n",
					av);
			directions();
		}
	}

	if (flag_v) {
		fprintf(stderr,"\n%s\n\n",version);
		if (!flag_q)
			sleep(2);
	}
	if (flag_m) {
		current_month = is_month(flag_m);
		if (current_month <= -1) {
			current_month = atoi(flag_m);
			if (current_month < 1 || current_month > 12) {
				fprintf(stderr,"Month '%s' not recognized\n");
				directions();
			} else {
				current_month--;
			}
		}
	}
	if (flag_y) {
		current_year = atoi(flag_y);
		if (current_year < 1760 || current_year > 3000) {
			fprintf(stderr,"Year must be between 1760 and 3000\n");
			directions();
		}
	}
}
